@@ -7,6 +7,7 @@
 #include <QQmlEngine>
 
 #include <kauthorized.h>
+#include <kconfigskeleton.h>
 #include <kcoreconfigskeleton.h>
 
 /*!
@@ -29,4 +30,10 @@ struct KCoreConfigSkeletonForeign {
     QML_FOREIGN(KCoreConfigSkeleton)
 };
 
+struct KConfigSkeletonForeign {
+    Q_GADGET
+    QML_ANONYMOUS
+    QML_FOREIGN(KConfigSkeleton)
+};
+
 #endif
